Crate ovr_overlay_sys

Structs

DistortionCoordinates_t
Used to return the post-distortion UVs for each color channel. UVs range from 0 to 1 with 0,0 in the upper left corner of the source render target. The 0,0 to 1,1 range covers a single eye.
HiddenAreaMesh_t
The mesh to draw into the stencil (or depth) buffer to perform early stencil (or depth) kills of pixels that will never appear on the HMD. This mesh draws on all the pixels that will be hidden after distortion.
HmdMatrix34_t
HmdMatrix44_t
HmdRect2_t
HmdVector2_t
IVROverlay
IVRSystem
Texture_t
TrackedDevicePose_t
describes a single pose for a tracked object
VRControllerState001_t
Holds all the state of a controller at one moment in time.
VREvent_t
An event posted by the server to all running applications
VROverlayIntersectionMaskPrimitive_t
VROverlayIntersectionParams_t
VROverlayIntersectionResults_t
VROverlayProjection_t
Defines the project used in an overlay that is using SetOverlayTransformProjection
VRTextureBounds_t
Allows the application to control what part of the provided texture will be used in the frame buffer.

Enums

EColorSpace
EDeviceActivityLevel
Level of Hmd activity
EGamepadTextInputLineMode
EGamepadTextInputMode
EHiddenAreaMeshType
ETextureType
ETrackedControllerRole
Describes what specific role associated with a tracked device
ETrackedDeviceClass
Describes what kind of object is being tracked at a given ID
ETrackedDeviceProperty
Each entry in this enum represents a property that can be retrieved about a tracked device. Many fields are only valid for one ETrackedDeviceClass.
ETrackedPropertyError
Used to return errors that occur when reading properties.
ETrackingUniverseOrigin
Identifies which style of tracking origin the application wants to use for the poses it is requesting
EVRApplicationType
enum values to pass in to VR_Init to identify whether the application will draw a 3D scene.
EVRButtonId
VR controller button and axis IDs
EVRControllerAxisType
Identifies what kind of axis is on the controller at index n. Read this type with pVRSystem->Get( nControllerDeviceIndex, Prop_Axis0Type_Int32 + n );
EVREventType
The types of events that could be posted (and what the parameters mean for each event type)
EVREye
EVRFirmwareError
error codes for firmware
EVRInitError
error codes returned by Vr_Init
EVROverlayError
Errors that can occur around VR overlays
VRMessageOverlayResponse
VROverlayFlags
Overlay control settings
VROverlayInputMethod
Types of input supported by VR Overlays
VROverlayTransformType
Allows the caller to figure out which overlay transform getter to call.

Traits

ToCppString

Functions

VROverlay
VRSystem
VR_GetVRInitErrorAsSymbol
Returns the name of the enum value for an EVRInitError. This function may be called outside of VR_Init()/VR_Shutdown().
VR_Init
Finds the active installation of the VR API and initializes it. The provided path must be absolute or relative to the current working directory. These are the local install versions of the equivalent functions in steamvr.h and will work without a local Steam install.
VR_Shutdown
unloads vrclient.dll. Any interface pointers from the interface are invalid after this point
make_string

Type Aliases

PropertyTypeTag_t
TrackedDeviceIndex_t
Used to pass device IDs to API calls
VRControllerState_t
Holds all the state of a controller at one moment in time.
VROverlayHandle_t
used to refer to a single VR overlay