Structs
- Distortion
Coordinates_ t - Used to return the post-distortion UVs for each color channel. UVs range from 0 to 1 with 0,0 in the upper left corner of the source render target. The 0,0 to 1,1 range covers a single eye.
- Hidden
Area Mesh_ t - The mesh to draw into the stencil (or depth) buffer to perform early stencil (or depth) kills of pixels that will never appear on the HMD. This mesh draws on all the pixels that will be hidden after distortion.
- HmdMatrix34_
t - HmdMatrix44_
t - HmdRect2_
t - HmdVector2_
t - IVROverlay
- IVRSystem
- Texture_
t - Tracked
Device Pose_ t - describes a single pose for a tracked object
- VRController
State001_ t - Holds all the state of a controller at one moment in time.
- VREvent_
t - An event posted by the server to all running applications
- VROverlay
Intersection Mask Primitive_ t - VROverlay
Intersection Params_ t - VROverlay
Intersection Results_ t - VROverlay
Projection_ t - Defines the project used in an overlay that is using SetOverlayTransformProjection
- VRTexture
Bounds_ t - Allows the application to control what part of the provided texture will be used in the frame buffer.
Enums
- EColor
Space - EDevice
Activity Level - Level of Hmd activity
- EGamepad
Text Input Line Mode - EGamepad
Text Input Mode - EHidden
Area Mesh Type - ETexture
Type - ETracked
Controller Role - Describes what specific role associated with a tracked device
- ETracked
Device Class - Describes what kind of object is being tracked at a given ID
- ETracked
Device Property - Each entry in this enum represents a property that can be retrieved about a tracked device. Many fields are only valid for one ETrackedDeviceClass.
- ETracked
Property Error - Used to return errors that occur when reading properties.
- ETracking
Universe Origin - Identifies which style of tracking origin the application wants to use for the poses it is requesting
- EVRApplication
Type - enum values to pass in to VR_Init to identify whether the application will draw a 3D scene.
- EVRButton
Id - VR controller button and axis IDs
- EVRController
Axis Type - Identifies what kind of axis is on the controller at index n. Read this type with pVRSystem->Get( nControllerDeviceIndex, Prop_Axis0Type_Int32 + n );
- EVREvent
Type - The types of events that could be posted (and what the parameters mean for each event type)
- EVREye
- EVRFirmware
Error - error codes for firmware
- EVRInit
Error - error codes returned by Vr_Init
- EVROverlay
Error - Errors that can occur around VR overlays
- VRMessage
Overlay Response - VROverlay
Flags - Overlay control settings
- VROverlay
Input Method - Types of input supported by VR Overlays
- VROverlay
Transform Type - Allows the caller to figure out which overlay transform getter to call.
Traits
Functions
- VROverlay⚠
- VRSystem⚠
- VR_
GetVR ⚠Init Error AsSymbol - Returns the name of the enum value for an EVRInitError. This function may be called outside of VR_Init()/VR_Shutdown().
- VR_Init⚠
- Finds the active installation of the VR API and initializes it. The provided path must be absolute or relative to the current working directory. These are the local install versions of the equivalent functions in steamvr.h and will work without a local Steam install.
- VR_
Shutdown ⚠ - unloads vrclient.dll. Any interface pointers from the interface are invalid after this point
- make_
string
Type Aliases
- Property
Type Tag_ t - Tracked
Device Index_ t - Used to pass device IDs to API calls
- VRController
State_ t - Holds all the state of a controller at one moment in time.
- VROverlay
Handle_ t - used to refer to a single VR overlay